/*
 * Robot.c
 *
 * Created: 11/18/2022 11:15:54 AM
 * Author : Aaron
 */ 
#define F_CPU 16000000L



//inclusions
#include <avr/io.h>
#include <util/delay.h>
#include <stdio.h>

#include "stepper_motor.h"	//access variables and definitions for stepper motor
#include "serial_mp3.h"


//function prototype 
void init_io(void); 
void init_timer(void);
void RobotVoice(void);

//Definitions 
#define PushButton (PINB & 0x07)



int main(void)
{

	uint8_t mp3_buf_vol[10] = {0x7E, 0xFF, 06, 06, 00, 00, 0x0F, 0xEF};	//buffer for sending mp3 commands
		
	 init_io();		//initialize ports
	init_MP3_UART(); //initialize mp3 communication
	uint16_t track_num; //initialize variable to hold track number
	
	_delay_ms(2000); //delay to give time for boot up
	Stepper_Position(180);
	
	//set volume on start up
	for(uint8_t i = 0; i<8;i++)
	{
		UART0_out(mp3_buf_vol[i]);
	}
	_delay_ms(1000);
	
	//Power ON lights
	for(uint8_t i = 0;i<3 ;i++)
	{
		PORTD = (1<<PORTD6);
		_delay_ms(500);
		PORTD = 0x00;
		_delay_ms(500); 
	}
	PORTD = (1<<PORTD6);
	RobotVoice();
	
    while (1) 
    {
		while (PushButton == 0x00) //wait for button to be pressed
		{
		}
		
		switch(PINB)
		{
			case 0x01: //button for just voice selection
			    
				RobotVoice();
				MouthLights();
				break;
			
			case 0x02:	//button for clockwise rotation
				Stepper_Position(45);
				_delay_ms(500);
				RobotVoice();
				MouthLights();
				break;
				
			case 0x04:	//button for counter-clockwise location
				Stepper_PositionR(45);
				_delay_ms(500);
				RobotVoice();
				MouthLights();
				break;
       }	
     }
}

void init_io(void)
{
	DDRB = 0xF8;	//Port B as input for push buttons
	PORTB = 0x07;	//enable pull up resistors 
	
	DDRC = 0xFF;	//PORT C as output for lights and stepper motor
	PORTC = 0x00;	//Output initially Off
	
	DDRD = 0xC0;	//PORT D.6 and 7 as output for LEDs
	PORTD = 0x3F;	//set port D to initially off
	
}

void init_timer(void)
{
	//FAST PWM, Active Low 
	
	//timer 0/2
	TCCR0A = (1<<COM0A1) | (1<<COM0A0)|(1<<COM0B1) | (1<<COM0B0)|(1<<WGM01)|(1<<WGM00);
	TCCR2A = (1<<COM2A1) | (1<<COM2A0)|(1<<COM2B1) | (1<<COM2B0)|(1<<WGM21)|(1<<WGM20);
	
	//timer 1
	TCCR1A = (1<<COM1A1) | (1<<COM1A0)|(1<<COM1B1) | (1<<COM1B0)|(1<<WGM10);
	TCCR1B = (1<<WGM12);
	 
	//set Pre-scale to 1024 (60Hz)
	TCCR0B |= (1<<CS02)| (1<<CS00);
	TCCR1B |= (1<<CS12)| (1<<CS10);
	TCCR2B |= (1<<CS22)| (1<<CS21)|(CS20);
}

void RobotVoice(void)
{
	uint8_t mp3_buf[10] = {0x7E, 0xFF, 0x06, 0x03, 0x00, 0x00, 0x01, 0xEF};	//buffer for sending mp3 commands
	
	uint8_t track_num = (rand() % 4) + 1;
	
	mp3_buf[6] = track_num;
	
	for(uint8_t i = 0; i<8;i++)
	{
		UART0_out(mp3_buf[i]);
	}
	_delay_ms(500);
}

void MouthLights (void)
{
	for(uint8_t i; i<5 ;i++)
	{
		PORTD = 0xC0;
		_delay_ms(250);
		PORTD = 0x40;
		_delay_ms(250);
	}
	
}

